===================
Roadmap
===================

wanted features
---------------

wordir control
  common ops to change the state of the workingtree
workdir status
  get the file states of the worktree
repo access
  find repos, get worktrees from them
histbrowse
  work with the history
branchman
  manage branches



Status
--------

======== ======= ======= ========== =========
VCS      Workdir Repo    histbrowse branchman
======== ======= ======= ========== =========
hg       yes     partial no         no
bzr      yes     partial no         no
svn      yes     partial no         no
git      messy   partial no         no
======== ======= ======= ========== =========


